<h1 align="center">📻 Emitter Tools</h1>
This library provides tools for working with event emitters.

## 💻 Installation

This package is [published to PyPI as `babichjacob-emitter-tools`](https://pypi.org/project/babichjacob-emitter-tools/).

## 🛠 Usage

The various functions this library provides are (mostly) documented individually (see their docstrings).

## 😵 Help! I have a question

Create an issue and I'll try to help.

## 😡 Fix! There is something that needs improvement

Create an issue or pull request and I'll try to fix.

## 📄 License

MIT

## 🙏 Attribution

_This README was generated with ❤️ by [readme-md-generator](https://github.com/kefranabg/readme-md-generator)_
